* code to support DPJ, "What Mat[t]hieu really did ....."

* now repeat Chemin analysis - different sequence to MC's "analysis.do", mainly to follow sequence in Chemin, 2008

capture log close
clear
clear mata
set more off

local basepath = "C:\data\PnK"	// base path for PnK project
global dofiles  "`basepath'\PnKDoFiles\jdsresponse"	/*  do files for jds response */
global workingpath  "`basepath'\working"
global additionaldatapath = "`basepath'\additionaldata"

log using "${workingpath}\replytochemin.log", replace

**** We don't follow order in Chemin "analysis.do" as want to compile descriptives first, then logits. 

*********************************************************************************************************
******descriptive statistics and the 2 other specifications a little bit affected by the use of idstring
*********************************************************************************************************

use "${workingpath}\analysis_original_data.dta", clear

* this is not the table 1 descriptives
sum part assetlanded assettransport assetequip assetother savings nfeexpense nfeown nfeowntime nfeasset nferevenue sales livevalue agrcost agrincome HHlandirrigated hhsize nonagrwage nonagrwagehh agrwage agrwagehh fed med mar rese age2 age3 age4 fliv mliv HGC sex scohab age landHHpar landHHbro landHHsis landHHSPpar landHHSPbro landHHSPsis HHland HGChead sexhead agehead adultmale if thana~=25 & thana~=26 & thana~=27 & thana~=28 & thana~=29


* the first set of columns are for treatment villages, the second with all  villages, both with whole population and no no land restriction 
* the third set are those reported in Chemin, 2008

* this is descriptives - no village level dummies
sum HGC sex age agehead adultmale landHHpar landHHbro  HGCdummy savings nfeown livevalue hhsize nonagrwage agrwage age2  age4 // uses whole sample without age restriction // if mcsample
tabstat HGC sex age agehead adultmale landHHpar landHHbro  HGChead HGCdummy savings nfeown livevalue hhsize nonagrwage agrwage age2  age4 , save s(n mean sd)  // uses whole sample without age restriction // if mcsample
mat mc_descriptives = r(StatTotal)
mat mc_descriptives = mc_descriptives'
esttab matrix(mc_descriptives, fmt(0 3 3))

* descriptives includinng Table 1 Col 1
do "${dofiles}\descriptives.do" /* table 1 column 1 */


* Chemin sample based on flopt < 50 decimals

estimates clear
* spec 1
logit part HGC sex age landHHpar landHHbro landHHsis landHHSPpar landHHSPbro landHHSPsis HHland HGChead sexhead agehead ///
	adultmale adultfemale scohab village11-village243 if thana~=25 & thana~=26 & thana~=27 & thana~=28 & thana~=29 ///
	& mcsample == 1
eststo _1

* spec2
logit part assetlanded assettransport assetequip assetother savings nfeexpense nfeown nfeowntime nfeasset nferevenue sales ///
	livevalue agrcost agrincome HHlandirrigated hhsize nonagrwage nonagrwagehh agrwage agrwagehh ///
	fed med mar rese age2 age3 age4 fliv mliv HGC sex scohab age ///
	landHHpar landHHbro landHHsis landHHSPpar landHHSPbro landHHSPsis HHland ///
	HGChead sexhead agehead adultmale village11-village243 ///
	if thana~=25 & thana~=26 & thana~=27 & thana~=28 & thana~=29 ///
	& mcsample == 1
eststo _2

* spec 3
logit part sex age agehead adultmale HGCdummy savings nfeown livevalue hhsize nonagrwage agrwage age2 age3 age4 agrincome HHland  fed med mar  mliv village11-village243 ///
	if thana~=25 & thana~=26 & thana~=27 & thana~=28 & thana~=29 ///
	& HHland <= 50
eststo _3, title(Chemin Table1 Col4)

/*
* MC code
******************now we absolutely need to predict WITHOUT the effect of the village(because for the no access, we don't have any village dummy)

forvalues i=11(1) 243{
	capture replace village`i'=0 if village`i'~=.
	}

predict ps
*/

* predict for treatment villages with village fixed effects
predict psmc0 if e(sample)	// ps with village dummies for treatment villages only

* predict propensity score without village level dummies.
destring village, force replace
levelsof village, local(village)
foreach i in `village' {		
	tempvar _`i'
	qui gen _`i' = village`i'
	qui capture replace village`i'=0 if village`i'~=.
	}
predict ps	// ps as described in Chemin - without village covariates
foreach i in `village' {		/* replace recoded village dummies with original values */
	drop village`i' 
	qui gen village`i' = _`i'
	}
drop _*

* dpj sample based on halab
logit part sex age agehead adultmale HGCdummy savings nfeown livevalue hhsize nonagrwage agrwage age2 age3 age4 agrincome halab_mc1  fed med mar  mliv village11-village243 ///
	if thana~=25 & thana~=26 & thana~=27 & thana~=28 & thana~=29 ///
	& halab_mc1 <= 50
eststo _3a, title(Chemin Table1 Col3 DPJ)
estadd mean

* predict with village dummies
predict psdpj0 if e(sample)

levels village, local(village)
foreach i in `village' {		
	tempvar _`i'
	qui gen _`i' = village`i'
	qui capture replace village`i'=0 if village`i'~=.
	}
predict psdpj
foreach i in `village' {		/* replace recoded village dummies with original values */
	drop village`i' 
	qui gen village`i' = _`i'
	}
drop _*

pwcorr ps*

* Specs 1-3 of Chemin Table 1
esttab _1 _2 _3,  b se keep(HGC sex age agehead adultmale landHHpar landHHbro  HGCdummy savings nfeown livevalue hhsize nonagrwage agrwage age2  age4) ///
	star(* 0.10 ** 0.05 *** 0.01)

* graphs of pscores

tw hist ps if part == 1 & thana <= 24 & mcsample, frac yscale(range(0 1)) ///
	xlabel(0(.5)1) ylabel(0(0.5)1) bin(15) title("participants", ///
	size(small)) name("figure2", replace) nodraw
tw hist ps if part == 0 & thana <= 24 & mcsample, frac yscale(range(0 1)) ///
	xlabel(0(.5)1) ylabel(0(0.5)1) bin(15) ///
	title("non-participants in villages with access to microfinance", ///
	size(small)) name("figure3", replace) nodraw
tw hist ps if part == 0 & thana > 24 & mcsample, frac yscale(range(0 1)) ///
	xlabel(0(.5)1) ylabel(0(0.5)1) bin(15) ///
	title("non-participants in villages without access to microfinance", ///
	size(small)) name("figure4", replace) nodraw

gr combine figure2 figure3 figure4, col(1) xsize(7.6) ysize(11.5) title("Distribution of corrected propensity scores", size(small)) note(specification 3)  imargin(zero)

****matching:
gen lgpercaexpenditure=log(percaexpenditure)
qui ren lgpercaexpenditure e
* added by RPJ -  detrend consumption as specified by Chemin
xi i.village, noomit
qui reg e _Iv*, nocons
predict e_e, residuals
save "${workingpath}impact.DTA", replace

*** now do psmatch2 with Chemin  sample 
* see analysis.do for Chemin matching code

cap prog drop store 
program define store 
* store results of kernel matching
local i = `1'
	local diff = r(att)	 // extract att & seatt and store in resutls matrix
	local semean = r(seatt)
*	local i = 1
	mat results[`i', 1] = `i'
	mat results[`i', 2] = `diff'
	mat results[`i', 3] = `semean'
	local sd = `semean' * sqrt(`diff')
	qui sum _treated			// extract  p- & t-values
	local n = r(sum) - 1
	local pdiff = 2*ttail(`n', abs(`diff'/`semean'))
	local tdiff = `diff' / `semean'
	mat results[`i', 4] = `pdiff'
	mat results[`i', 5] = `tdiff'
end

cap prog drop store1 
program define store1 
*syntax store1 row matrix
* store results of bootstrapping
set trace on
args i results

	mat b = e(b)
	local b = b[1,1]	 // extract att & seatt and store in results matrix
	mat se = e(se)
	local seb = se[1,1]
	local t = `b' / `seb'
	local n = e(N)
	local p = 2 * ttail(`n', abs(`t'))
	mat ci = e(ci_normal)
*	local i = 1
	mat `results'[`i', 1] = `i'
	mat `results'[`i', 2] = `b'
	mat `results'[`i', 3] = `seb'
	mat `results'[`i', 4] = `p'
	mat `results'[`i', 5] = `t'
	mat `results'[`i', 6] = ci[1,1]
	mat `results'[`i', 7] = ci[2,1]
end


cap prog drop sa_results
prog def sa_results, rclass
args r1 sa_results results1
* get results or rsens
tempname results
mat `results' = `sa_results'
local rows = rowsof(`results')
sca ns10u = 0
sca ns10l = 0
sca gamma = 1
forval r = 1/`rows' {
	noisily di "`r'"
	if `results'[1, 3] <= 0.1 {	// SOMETIMES RSENS RETURNS LARGER VALUES
		if `results'[`r', 3]  > 0.1 {
			sca gamma = `results'[`r', 1]
			sca ns10u = `results'[`r', 2]
			sca ns10l = `results'[`r', 3] 
			continue, break
		}
		if `results'[`r', 2]  > 0.1 {
			sca gamma = `results'[`r', 1]
			sca ns10l = `results'[`r', 2] 
			sca ns10u = `results'[`r', 3]
			continue, break
		}
	}
	if `results'[1, 3] >= 0.1 { // SEARCH TILL ONE OF THE VALUES BECOMES VERY SMALL
		
		if `results'[`r', 3]  < 0.0001 {
			sca gamma = `results'[`r', 1]
			sca ns10u = `results'[`r', 2]
			sca ns10l = `results'[`r', 3] 
			continue, break
		}
		if `results'[`r', 2]  <= 0.0001 {
			sca gamma = `results'[`r', 1]
			sca ns10l = `results'[`r', 2] 
			sca ns10u = `results'[`r', 3]
			continue, break
		}
	}
	
}
di "lower  " ns10l "   upper  " ns10u
mat `results1'[`r1', 6] = gamma
mat `results1'[`r1', 7] = ns10l
mat `results1'[`r1', 8] = ns10u

return mat sa_results = `results'
end



use "${workingpath}impact.DTA", clear

mat results = J(12, 7, .)
mat colnames results = number diff sediff pdif tdiff cilo cihi
* rows are author, sample, prediction, 
mat rownames results = mc_tr_e mc_tr_ee mc_c_e mc_c_ee dpj_tr_e dpj_tr_ee dpj_c_e dpj_c_ee mc_tr_e_np mc_tr_ee_np dpj_tr_e_np dpj_tr_ee_np

* pscore with operated land sample (flopt < 50 - Chemin's variable name is HHland)

* treatment villages

*uncorrected consumption
psmatch2 part if thana <= 24 & mcsample == 1 ///
	, outcome(e) pscore(ps) kernel k(normal) bwidth(0.05) 
	
bootstrap r(att) : psmatch2 part if thana <= 24 & mcsample == 1 ///
	, outcome(e) pscore(ps) kernel k(normal) bwidth(0.05) 
* Table 3 Col 3
store1 1 results

* correct log of per capita expenditure
bootstrap r(att) : psmatch2 part if thana <= 24 & mcsample == 1 ///
	, outcome(e_e) pscore(ps) kernel k(normal) bwidth(0.05) 
* Table 3 Col 4 
store1 2 results

* control villages

* uncorrected consumption
bootstrap r(att) : psmatch2 part if (part == 1 | (thana >= 25 & thana <= 29)) & mcsample == 1 ///
	, outcome(e) pscore(ps) kernel k(normal) bwidth(0.05) 
* table 3 Col 5 row 2 (Control villages)
store1 3 results

* correct log of per captia expenditure
bootstrap r(att) : psmatch2 part if (part == 1 | (thana >= 25 & thana <= 29)) & mcsample == 1 ///
	, outcome(e_e) pscore(ps) kernel k(normal) bwidth(0.05) 
* table 3 Col 6 row 2 (Control villages)
store1 4 results

mat list results 

* pscore with owned land (halab <= 50) i.e. selection by owned land

* DPJ sample
* treatment villages
bootstrap r(att) : psmatch2 part if thana <= 24 & dpjsample == 1 ///
	, outcome(e) pscore(psdpj) kernel k(normal) bwidth(0.05) 
* 
store1 5 results
* correct log of per captia expenditure
bootstrap r(att) : psmatch2 part if thana <= 24 & dpjsample == 1 ///
	, outcome(e_e) pscore(psdpj) kernel k(normal) bwidth(0.05) 
* 
store1 6 results

* control villages
bootstrap r(att) : psmatch2 part if (part == 1 | (thana >= 25 & thana <= 29)) & dpjsample == 1 ///
	, outcome(e) pscore(psdpj) kernel k(normal) bwidth(0.05) 
* 
store1 7 results
* correct log of per captia expenditure
bootstrap r(att) : psmatch2 part if (part == 1 | (thana >= 25 & thana <= 29)) & dpjsample == 1 ///
	, outcome(e_e) pscore(psdpj) kernel k(normal) bwidth(0.05) 
* 
store1 8 results

mat list results
esttab matrix(results, fmt(3 3 3 3 3 3 3 3))

* now have correct control groups.l
gen femalepart = sex == 0 & part == 1
bys nh (idstring) : egen femaleparthh = max(femalepart)
gen malepart = sex == 1 & part == 1
bys nh (idstring): egen maleparthh = max(malepart)
gen parthh = femaleparthh == 1 | maleparthh == 1


* treatment villages only 
* control group is non-prticipating people in treatment villages in non-participating households 
* - whether participant is male or female
/* conditions are: 
in treatment thana AND 
HHland < 50 AND 
(either a participant OR (neither  a participant NOR a member of a household with a participant))

*/

psmatch2 part if thana <= 24 & mcsample == 1 ///
	& (part == 1 | (part == 0 & parthh == 0 )), ///		
	outcome(e) pscore(ps) kernel k(normal) bwidth(0.05)
	
bootstrap r(att) : psmatch2 part if thana <= 24 & mcsample == 1 ///
	& (part == 1 | (part == 0 & parthh == 0 )), ///		
	outcome(e) pscore(ps) kernel k(normal) bwidth(0.05) 
* uncorrected expenditure
* table 3 Col 5 row 1 (Control is treatment  villages)
store1 9 results

* correct log of per captia expenditure
psmatch2 part if thana <= 24 & mcsample == 1 ///
	& (part == 1 | (part == 0 & parthh == 0 )), ///	
	outcome(e_e) pscore(ps) kernel k(normal) bwidth(0.05)
	
bootstrap r(att) : psmatch2 part if thana <= 24 & mcsample == 1 ///
	& (part == 1 | (part == 0 & parthh == 0 )), ///	
	outcome(e_e) pscore(ps) kernel k(normal) bwidth(0.05) 
* corrected expenditure
* table 3 Col 6 row 1 (Control is treatment villages)
store1 10 results

esttab matrix(results, fmt(0 4 4 4 4 4 4))

* estimates for halab < 50
* treatment villages
bootstrap r(att) : psmatch2 part if thana <= 24 & dpjsample == 1 ///
	& (part == 1 | (part == 0 & parthh == 0 )), ///		
	outcome(e) pscore(psdpj) kernel k(normal) bwidth(0.05) 
store1 11 results
* correct log of per captia expenditure
bootstrap r(att) : psmatch2 part if thana <= 24 & dpjsample == 1 ///
	& (part == 1 | (part == 0 & parthh == 0 )), ///		
	outcome(e_e) pscore(psdpj) kernel k(normal) bwidth(0.05) 
store1 12 results
**************************************************************************
* Table 3 - not all results reported (i.e. only rows 1,2, 3, 4, 9 & 10   *
**************************************************************************
esttab matrix(results, fmt(0 4 4 4 4 4 4))
mat results1 = results

***********************************************************************************************
* now test sensitivity - since only control village comparison is significant only run these
***********************************************************************************************

mat results = J(8, 10, .)
mat colnames results = number diff sediff pdif tdiff gamma cihi cilo
* rows are author, sample, prediction, method
mat rownames results = mc_c_e_k mc_c_e_nn mc_c_ee_k mc_c_ee_nn   dpj_c_e_k dpj_c_e_nn dpj_c_ee_k dpj_c_ee_nn 

* now do sensitivity analysis - need to do nearest neighbour matching
* including members of households 
display "control villages"

psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& mcsample == 1, outcome(e) ///
	pscore(ps) kernel k(normal) bwidth(0.05) 

* Table 4 Col 1 row 1
store 1

* 20 nn
psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& mcsample == 1, outcome(e) ///
	pscore(ps) n(20)
* Table 4 Col (2) row 2
store 2
* Table 4 col 3 row 1
rsens e, gamma(1(.1)2)	// becomes vulnerable at gamma 1.1 - 1.2
mat rsensvalues = r(rsensvalues)
sa_results 2 rsensvalues results 

* now with corrected consumption
psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& mcsample == 1, outcome(e_e) ///
	pscore(ps) kernel k(normal) bwidth(0.05)
* Table 4 Col 1 row 2
store 3

* 20 nn 
psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& mcsample == 1, outcome(e_e) ///
	pscore(ps) n(20)
* Table 4 Col 2 row 2
store 4
* Table 4 Col 3 row 2
rsens e, gamma(1(.1)2)	// becomes vulnerable at gamma 1.1 - 1.2
mat rsensvalues = r(rsensvalues)
sa_results 4 rsensvalues results 


* dpj sample - halab
* uncorrected 
psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& dpjsample == 1, outcome(e) ///
	pscore(psdpj) kernel k(normal) bwidth(0.05) 
* Table 4 Col 1 row 3
store 5
* 20 nn
psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& dpjsample == 1, outcome(e) ///
	pscore(psdpj) n(20)
* Table 4 Col 2 row 3
store 6
* Table 4 Col 3 row 3
rsens e, gamma(1(.1)2)	// becomes vulnerable at gamma 1.1 - 1.2
mat rsensvalues = r(rsensvalues)
sa_results 6 rsensvalues results 

* now with corrected consumption
psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& mcsample == 1, outcome(e_e) ///
	pscore(psdpj) kernel k(normal) bwidth(0.05)
* Table 4 Col 1 row 4
store 7
* 20 nn 
psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& dpjsample == 1, outcome(e_e) ///
	pscore(ps) n(20)
* Table 4 Col 2 row 4
store 8
* Table 4 Col 3 row 4
rsens e_e, gamma(1(.1)3)	// becomes vulnerable at gamma >2
mat rsensvalues = r(rsensvalues)
sa_results 8 rsensvalues results 


*mat list results
esttab matrix(results, fmt(0 4 4 4 4 4 4 4))

mat results2 = results, results


* redo for nn with with rbounds for sensitivity analysi

* 1 nn 
psmatch2 part if (part==1 | (thana >= 25 & thana <= 29)) ///
	& dpjsample == 1, outcome(e_e) ///
	pscore(ps) n(1)
*store 9
rbounds e_e if (part==1 | (thana >= 25 & thana <= 29))  & dpjsample == 1, gamma(1(.2)2)


* other dependent variables
* gen lgwnonlandasset=log(wnonlandasset)
* psmatch2 part if thana~=25 & thana~=26 & thana~=27 & thana~=28 & thana~=29, outcome(lgwnonlandasset) pscore(ps) kernel k(normal) bwidth(0.05) 

capture log close